PALM-meteo: palmmeteo.dispatch Namespace Reference

PALM-meteo

Functions
palmmeteo.dispatch Namespace Reference

## Functions
def | build_exec_queue (event, from_plugins)
def | execute_event (event, from_plugins)
def | run (argv)
def | main ()

## Function Documentation

## ◆ build_exec_queue()

def palmmeteo.dispatch.build_exec_queue | ( |  | event,
|  |  | from_plugins
| ) |  |

## ◆ execute_event()

def palmmeteo.dispatch.execute_event | ( |  | event,
|  |  | from_plugins
| ) |  |

## ◆ main()

def palmmeteo.dispatch.main | ( |  | ) |

## ◆ run()

def palmmeteo.dispatch.run | ( |  | argv | ) |